@@ -9,11 +9,11 @@ action requires 'image-partition' action to be executed before it.
 After this action has ran, subsequent actions are executed on the mounted output
 image.
 
- # Yaml syntax:
- - action: filesystem-deploy
-   setup-fstab: bool
-   setup-kernel-cmdline: bool
-   append-kernel-cmdline: arguments
+	# Yaml syntax:
+	- action: filesystem-deploy
+	  setup-fstab: bool
+	  setup-kernel-cmdline: bool
+	  append-kernel-cmdline: arguments
 
 Optional properties:
 
@@ -31,7 +31,6 @@ import (
 	"errors"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"log"
 	"os"
 	"path"
@@ -54,52 +53,50 @@ func NewFilesystemDeployAction() *FilesystemDeployAction {
 	return fd
 }
 
-func (fd *FilesystemDeployAction) setupFSTab(context *debos.DebosContext) error {
+func (fd *FilesystemDeployAction) setupFSTab(context *debos.Context) error {
 	if context.ImageFSTab.Len() == 0 {
-		return errors.New("Fstab not generated, missing image-partition action?")
+		return errors.New("fstab not generated, missing image-partition action?")
 	}
 
 	log.Print("Setting up /etc/fstab")
 
 	err := os.MkdirAll(path.Join(context.Rootdir, "etc"), 0755)
 	if err != nil {
-		return fmt.Errorf("Couldn't create etc in image: %v", err)
+		return fmt.Errorf("couldn't create etc in image: %w", err)
 	}
 
 	fstab := path.Join(context.Rootdir, "etc/fstab")
 	f, err := os.OpenFile(fstab, os.O_RDWR|os.O_CREATE, 0755)
-	defer f.Close()
-
 	if err != nil {
-		return fmt.Errorf("Couldn't open /etc/fstab: %v", err)
+		return fmt.Errorf("couldn't open /etc/fstab: %w", err)
 	}
+	defer f.Close()
 
 	_, err = io.Copy(f, &context.ImageFSTab)
 
 	if err != nil {
-		return fmt.Errorf("Couldn't write /etc/fstab: %v", err)
+		return fmt.Errorf("couldn't write /etc/fstab: %w", err)
 	}
 
 	return nil
 }
 
-func (fd *FilesystemDeployAction) setupKernelCmdline(context *debos.DebosContext) error {
+func (fd *FilesystemDeployAction) setupKernelCmdline(context *debos.Context) error {
 	var cmdline []string
 
 	log.Print("Setting up /etc/kernel/cmdline")
 
 	err := os.MkdirAll(path.Join(context.Rootdir, "etc", "kernel"), 0755)
 	if err != nil {
-		return fmt.Errorf("Couldn't create etc/kernel in image: %v", err)
+		return fmt.Errorf("couldn't create etc/kernel in image: %w", err)
 	}
 	path := path.Join(context.Rootdir, "etc/kernel/cmdline")
-	current, _ := ioutil.ReadFile(path)
+	current, _ := os.ReadFile(path)
 	f, err := os.OpenFile(path, os.O_RDWR|os.O_CREATE, 0755)
-	defer f.Close()
-
 	if err != nil {
-		return fmt.Errorf("Couldn't open /etc/kernel/cmdline: %v", err)
+		return fmt.Errorf("couldn't open /etc/kernel/cmdline: %w", err)
 	}
+	defer f.Close()
 
 	cmdline = append(cmdline, strings.TrimSpace(string(current)))
 	cmdline = append(cmdline, context.ImageKernelRoot)
@@ -110,19 +107,19 @@ func (fd *FilesystemDeployAction) setupKernelCmdline(context *debos.DebosContext
 
 	_, err = f.WriteString(strings.Join(cmdline, " ") + "\n")
 	if err != nil {
-		return fmt.Errorf("Couldn't write /etc/kernel/cmdline: %v", err)
+		return fmt.Errorf("couldn't write /etc/kernel/cmdline: %w", err)
 	}
 
 	return nil
 }
 
-func (fd *FilesystemDeployAction) Run(context *debos.DebosContext) error {
+func (fd *FilesystemDeployAction) Run(context *debos.Context) error {
 	/* Copying files is actually silly hafd, one has to keep permissions, ACL's
 	 * extended attribute, misc, other. Leave it to cp...
 	 */
 	err := debos.Command{}.Run("Deploy to image", "cp", "-a", context.Rootdir+"/.", context.ImageMntDir)
 	if err != nil {
-		return fmt.Errorf("rootfs deploy failed: %v", err)
+		return fmt.Errorf("rootfs deploy failed: %w", err)
 	}
 	context.Rootdir = context.ImageMntDir
 	context.Origins["filesystem"] = context.ImageMntDir
