@@ -25,6 +25,7 @@ If destination isn't set '/' of the rootfs will be used.
 package actions
 
 import (
+	"errors"
 	"fmt"
 	"log"
 	"os"
@@ -45,6 +46,10 @@ func (overlay *OverlayAction) Verify(context *debos.Context) error {
 		return err
 	}
 
+	if len(overlay.Source) == 0 && len(overlay.Origin) == 0 {
+		return errors.New("'source' and 'origin' properties can't both be empty")
+	}
+
 	/* if origin is the recipe, check the path exists on disk */
 	if len(overlay.Origin) == 0 || overlay.Origin == "recipe" {
 		sourceDir := path.Join(context.RecipeDir, overlay.Source)
