@@ -7,17 +7,26 @@ Construct the target rootfs with pacstrap tool.
 	- action: pacstrap
 	  config: <in-tree pacman.conf file>
 	  mirror: <in-tree mirrorlist file>
+	  packages: <list of packages to install>
 
 Mandatory properties:
 
   - config -- the pacman.conf file which will be used through the process
   - mirror -- the mirrorlist file which will be used through the process
+
+Optional properties:
+
+  - packages -- list of packages to install
+    If no packages are specified to be installed, pacstrap will install
+    the base metapackage by default. The base metapackage is only automatically
+    installed when this list is empty, this means that it must be added to the
+    list when adding packages.
 */
 package actions
 
 import (
 	"fmt"
-	"io/ioutil"
+	"io/fs"
 	"os"
 	"path"
 
@@ -27,21 +36,22 @@ import (
 
 type PacstrapAction struct {
 	debos.BaseAction `yaml:",inline"`
-	Config           string `yaml:"config"`
-	Mirror           string `yaml:"mirror"`
+	Config           string   `yaml:"config"`
+	Mirror           string   `yaml:"mirror"`
+	Packages         []string `yaml:"packages"`
 }
 
-func (d *PacstrapAction) listOptionFiles(context *debos.DebosContext) ([]string, error) {
+func (d *PacstrapAction) listOptionFiles(context *debos.Context) ([]string, error) {
 	files := []string{}
 
 	if d.Config == "" {
-		return nil, fmt.Errorf("No config file set")
+		return nil, fmt.Errorf("no config file set")
 	}
 	d.Config = debos.CleanPathAt(d.Config, context.RecipeDir)
 	files = append(files, d.Config)
 
 	if d.Mirror == "" {
-		return nil, fmt.Errorf("No mirror file set")
+		return nil, fmt.Errorf("no mirror file set")
 	}
 	d.Mirror = debos.CleanPathAt(d.Mirror, context.RecipeDir)
 	files = append(files, d.Mirror)
@@ -49,7 +59,7 @@ func (d *PacstrapAction) listOptionFiles(context *debos.DebosContext) ([]string,
 	return files, nil
 }
 
-func (d *PacstrapAction) Verify(context *debos.DebosContext) error {
+func (d *PacstrapAction) Verify(context *debos.Context) error {
 	files, err := d.listOptionFiles(context)
 	if err != nil {
 		return err
@@ -65,11 +75,11 @@ func (d *PacstrapAction) Verify(context *debos.DebosContext) error {
 	return nil
 }
 
-func (d *PacstrapAction) PreNoMachine(context *debos.DebosContext) error {
+func (d *PacstrapAction) PreNoMachine(_ *debos.Context) error {
 	return fmt.Errorf("action requires fakemachine")
 }
 
-func (d *PacstrapAction) PreMachine(context *debos.DebosContext, m *fakemachine.Machine, args *[]string) error {
+func (d *PacstrapAction) PreMachine(context *debos.Context, m *fakemachine.Machine, _ *[]string) error {
 	mounts, err := d.listOptionFiles(context)
 	if err != nil {
 		return err
@@ -83,7 +93,7 @@ func (d *PacstrapAction) PreMachine(context *debos.DebosContext, m *fakemachine.
 	return nil
 }
 
-func (d *PacstrapAction) Run(context *debos.DebosContext) error {
+func (d *PacstrapAction) Run(context *debos.Context) error {
 	files := map[string]string{
 		"/etc/pacman.conf":         d.Config,
 		"/etc/pacman.d/mirrorlist": d.Mirror,
@@ -95,12 +105,12 @@ func (d *PacstrapAction) Run(context *debos.DebosContext) error {
 			return err
 		}
 
-		read, err := ioutil.ReadFile(src)
+		read, err := os.ReadFile(src)
 		if err != nil {
 			return err
 		}
 
-		if err = ioutil.WriteFile(dest, read, 0644); err != nil {
+		if err = os.WriteFile(dest, read, fs.FileMode(0644)); err != nil {
 			return err
 		}
 	}
@@ -110,17 +120,22 @@ func (d *PacstrapAction) Run(context *debos.DebosContext) error {
 	// Even if we did, blindly copying it might not be a good idea.
 	cmdline := []string{"pacman-key", "--init"}
 	if err := (debos.Command{}.Run("pacman-key", cmdline...)); err != nil {
-		return fmt.Errorf("Couldn't init pacman keyring: %v", err)
+		return fmt.Errorf("couldn't init pacman keyring: %w", err)
 	}
 
 	// When there's no explicit keyring suite we populate all available
 	cmdline = []string{"pacman-key", "--populate"}
 	if err := (debos.Command{}.Run("pacman-key", cmdline...)); err != nil {
-		return fmt.Errorf("Couldn't populate pacman keyring: %v", err)
+		return fmt.Errorf("couldn't populate pacman keyring: %w", err)
 	}
 
 	// Run pacstrap
 	cmdline = []string{"pacstrap", context.Rootdir}
+
+	if d.Packages != nil {
+		cmdline = append(cmdline, d.Packages...)
+	}
+
 	if err := (debos.Command{}.Run("pacstrap", cmdline...)); err != nil {
 		log := path.Join(context.Rootdir, "var/log/pacman.log")
 		_ = debos.Command{}.Run("pacstrap.log", "cat", log)
