@@ -44,6 +44,7 @@ package actions
 import (
 	"errors"
 	"github.com/go-debos/fakemachine"
+	"log"
 	"path"
 	"strings"
 
@@ -137,6 +138,10 @@ func (run *RunAction) doRun(context debos.Context) error {
 		label = run.Label
 	}
 
+	if context.Verbose {
+		log.Printf("Running command \"%s\"", cmdline)
+	}
+
 	// Command/script with options passed as single string
 	cmdline = append([]string{"sh", "-e", "-c"}, cmdline...)
 
